@@ -2,6 +2,8 @@
 
 from typing import Any, IO, Optional, TYPE_CHECKING
 
+__all__ = ["get_console", "reconfigure", "print", "inspect"]
+
 if TYPE_CHECKING:
     from .console import Console
 
@@ -25,6 +27,18 @@ def get_console() -> "Console":
     return _console
 
 
+def reconfigure(*args, **kwargs) -> None:
+    """Reconfigures the global console bu replacing it with another.
+
+    Args:
+        console (Console): Replacement console instance.
+    """
+    from rich.console import Console
+
+    new_console = Console(*args, **kwargs)
+    _console.__dict__ = new_console.__dict__
+
+
 def print(*objects: Any, sep=" ", end="\n", file: IO[str] = None, flush: bool = False):
     r"""Print object(s) supplied via positional arguments.
     This function has an identical signature to the built-in print.
@@ -55,9 +69,17 @@ def inspect(
     dunder: bool = False,
     sort: bool = True,
     all: bool = False,
+    value: bool = True
 ):
     """Inspect any Python object.
 
+    * inspect(<OBJECT>) to see summarized info.
+    * inspect(<OBJECT>, methods=True) to see methods.
+    * inspect(<OBJECT>, help=True) to see full (non-abbreviated) help.
+    * inspect(<OBJECT>, private=True) to see private attributes (single underscore).
+    * inspect(<OBJECT>, dunder=True) to see attributes begining with double underscore.
+    * inspect(<OBJECT>, all=True) to see all attributes.
+
     Args:
         obj (Any): An object to inspect.
         title (str, optional): Title to display over inspect result, or None use type. Defaults to None.
@@ -68,20 +90,25 @@ def inspect(
         dunder (bool, optional): Show attributes starting with double underscore. Defaults to False.
         sort (bool, optional): Sort attributes alphabetically. Defaults to True.
         all (bool, optional): Show all attributes. Defaults to False.
+        value (bool, optional): Pretty print value. Defaults to True.
     """
     _console = console or get_console()
     from rich._inspect import Inspect
 
+    # Special case for inspect(inspect)
+    is_inspect = obj is inspect
+
     _inspect = Inspect(
         obj,
         title=title,
-        help=help,
-        methods=methods,
-        docs=docs,
+        help=is_inspect or help,
+        methods=is_inspect or methods,
+        docs=is_inspect or docs,
         private=private,
         dunder=dunder,
         sort=sort,
         all=all,
+        value=value,
     )
     _console.print(_inspect)
 
